@@ -73,10 +73,14 @@ warnings.filterwarnings(
     message=" WARNING:root:The use of `check_types` is deprecated and does not have any effect.",
 )
 
-
-from plangym.control import Box2DEnv, ClassicControl, DMControlEnv, LunarLander  # noqa: E402
-from plangym.core import PlanEnv  # noqa: E402
-from plangym.registry import make  # noqa: E402
-from plangym.vectorization import ParallelEnv, RayEnv  # noqa: E402
 from plangym.version import __version__  # noqa: E402
-from plangym.videogames import AtariEnv, MarioEnv, MontezumaEnv, RetroEnv  # noqa: E402
+
+
+try:
+    from plangym.control import Box2DEnv, ClassicControl, DMControlEnv, LunarLander  # noqa: E402
+    from plangym.core import PlanEnv  # noqa: E402
+    from plangym.registry import make  # noqa: E402
+    from plangym.vectorization import ParallelEnv, RayEnv  # noqa: E402
+    from plangym.videogames import AtariEnv, MarioEnv, MontezumaEnv, RetroEnv  # noqa: E402
+except Exception:
+    pass
